RCKMessageEditMention class

编辑输入中一个已确认的 mention。

自定义编辑输入可用它保存用户 ID、原始文本和 UTF-16 文本范围,确保草稿 恢复及再次提交时不会把已删除或重排的 mention 错配给其他用户。

Constructors

RCKMessageEditMention({required String userId, required String text, required int start, required int end})
const

Properties

end int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
final
text String
final
userId String
final

Methods

copyWith({int? start, int? end}) RCKMessageEditMention
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited