RCKMessageReadReceiptConfig class

Constructors

RCKMessageReadReceiptConfig({bool enabled = true, bool showIndicator = true, RCKReadReceiptIndicatorConfig indicatorConfig = const RCKReadReceiptIndicatorConfig(), RCKReadReceiptDetailConfig detailConfig = const RCKReadReceiptDetailConfig()})
const

Properties

detailConfig RCKReadReceiptDetailConfig
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
indicatorConfig RCKReadReceiptIndicatorConfig
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showIndicator bool
是否在消息气泡旁显示已读状态标志。
final

Methods

copyWith({bool? enabled, bool? showIndicator, RCKReadReceiptIndicatorConfig? indicatorConfig, RCKReadReceiptDetailConfig? detailConfig}) RCKMessageReadReceiptConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited