RCKReadReceiptDisplayData class

Annotations

Constructors

RCKReadReceiptDisplayData({required RCIMIWConversationType conversationType, RCIMIWReadReceiptInfoV5? readReceiptInfo, RCIMIWReadReceiptResponseV5? readReceiptResponse})
const
RCKReadReceiptDisplayData.pending(RCIMIWConversationType conversationType)
const

Properties

actualReadRatio → double
no setter
conversationType → RCIMIWConversationType
final
displayState → RCKReadReceiptDisplayState
no setter
hashCode → int
The hash code for this object.
no setteroverride
isAuthoritative → bool
no setter
paintReadRatio → double
no setter
readCount → int
no setter
readReceiptInfo → RCIMIWReadReceiptInfoV5?
final
readReceiptResponse → RCIMIWReadReceiptResponseV5?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
no setter
unreadCount → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override