RCIMIWReferenceMessageStatus enum

Inheritance
Available extensions

Values

defaultValue → const RCIMIWReferenceMessageStatus

ZH

默认状态。

EN

Default status.

modified → const RCIMIWReferenceMessageStatus

ZH

被引用消息已修改。

EN

The referenced message has been modified.

recalled → const RCIMIWReferenceMessageStatus

ZH

被引用消息已撤回。

EN

The referenced message has been recalled.

deleted → const RCIMIWReferenceMessageStatus

ZH

被引用消息已删除。

EN

The referenced message has been deleted.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RCIMIWReferenceMessageStatus>
A constant List of the values in this enum, in order of their declaration.