RCKMessageEditConfig class

消息编辑页面级配置。

Constructors

RCKMessageEditConfig({bool enabled = true, RCKMessageEditInputConfig inputConfig = const RCKMessageEditInputConfig(), RCKMessageEditStatusConfig statusConfig = const RCKMessageEditStatusConfig(), RCKMessageEditStrings strings = const RCKMessageEditStrings()})
const

Properties

enabled bool
当前聊天页是否展示消息编辑能力。
final
hashCode int
The hash code for this object.
no setterinherited
inputConfig RCKMessageEditInputConfig
编辑输入区域配置。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusConfig RCKMessageEditStatusConfig
消息编辑状态展示配置。
final
strings RCKMessageEditStrings
默认文案配置。
final

Methods

copyWith({bool? enabled, RCKMessageEditInputConfig? inputConfig, RCKMessageEditStatusConfig? statusConfig, RCKMessageEditStrings? strings}) RCKMessageEditConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited