RCKMessageEditOptions class

消息编辑功能的应用级开关。

是否可编辑及可编辑时限由服务端应用设置决定;该配置只控制 Kit 是否启用 消息编辑相关的事件、草稿和界面能力。

Constructors

RCKMessageEditOptions({bool enabled = false})
const

Properties

enabled → bool
是否启用消息编辑功能。
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? enabled}) → RCKMessageEditOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited