RCKMessageEditStrings class

消息编辑默认文案。

Constructors

RCKMessageEditStrings({String edit = '编辑', String title = '编辑消息', String cancel = '取消', String confirm = '完成', String emoji = '表情', String expand = '展开', String collapse = '收起', String edited = '已编辑', String updating = '更新中', String failed = '更新失败,点击重试', String retryFailed = '重试失败,请稍后再试!', String unavailable = '编辑已过期', String remoteMessageMissing = '云端消息不存在,无法编辑', String messageDeleted = '消息已删除,无法保存', String messageRecalled = '消息已撤回,无法保存', String sensitiveContent = '编辑内容含有敏感信息,更新失败', String expired = '超过有效编辑时间,无法编辑', String referenceDeleted = '此消息已删除', String referenceRecalled = '此消息已撤回', String switchMessageTitle = '提示', String switchMessageContent = '正在编辑另一条消息,确定编辑当前消息后,则之前编辑的消息内容将丢失。', String switchMessageConfirm = '确定', String switchMessageCancel = '返回'})
const

Properties

cancel String
取消编辑操作名称。
final
collapse String
收起全屏编辑操作名称。
final
confirm String
确认编辑操作名称。
final
edit String
长按菜单中的编辑操作名称。
final
edited String
已编辑标记文案。
final
emoji String
表情面板操作名称。
final
expand String
展开全屏编辑操作名称。
final
expired String
超过编辑时限时的提示文案。
final
failed String
更新失败状态文案。
final
hashCode int
The hash code for this object.
no setterinherited
messageDeleted String
提交前确认原消息已删除时的提示文案。
final
messageRecalled String
原消息已撤回时的提示文案。
final
referenceDeleted String
被引用消息已删除时的预览文案。
final
referenceRecalled String
被引用消息已撤回时的预览文案。
final
remoteMessageMissing String
云端原消息不存在时的提示文案。
final
retryFailed String
更新失败后再次重试仍失败的提示文案。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitiveContent String
编辑内容触发内容审核时的提示文案。
final
switchMessageCancel String
切换取消操作名称。
final
switchMessageConfirm String
切换确认操作名称。
final
switchMessageContent String
切换正在编辑的消息时的确认内容。
final
switchMessageTitle String
切换正在编辑的消息时的确认标题。
final
title String
编辑输入区域标题。
final
unavailable String
当前消息不可编辑时的提示文案。
final
updating String
更新中状态文案。
final

Methods

copyWith({String? edit, String? title, String? cancel, String? confirm, String? emoji, String? expand, String? collapse, String? edited, String? updating, String? failed, String? retryFailed, String? unavailable, String? remoteMessageMissing, String? messageDeleted, String? messageRecalled, String? sensitiveContent, String? expired, String? referenceDeleted, String? referenceRecalled, String? switchMessageTitle, String? switchMessageContent, String? switchMessageConfirm, String? switchMessageCancel}) RCKMessageEditStrings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited