RCKInputFieldConfig class

输入框配置

Constructors

RCKInputFieldConfig({double? maxHeight = kInputFieldMaxHeight, Color? fillColor, InputBorder? border, InputBorder? focusedBorder, EdgeInsets contentPadding = const EdgeInsets.all(8.0), TextStyle? textStyle, String? hintText, TextStyle? hintStyle, Color? cursorColor, double borderRadius = 10.0, TextInputAction textInputAction = TextInputAction.send})

Properties

border → InputBorder?
边框样式
final
borderRadius → double
圆角大小
final
contentPadding → EdgeInsets
内部填充
final
cursorColor → Color?
光标颜色
final
fillColor → Color
no setter
focusedBorder → InputBorder?
聚焦时的边框样式
final
hashCode → int
The hash code for this object.
no setterinherited
hintStyle → TextStyle?
提示文本样式
final
hintText → String?
提示文本
final
maxHeight → double?
最大高度限制
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textInputAction → TextInputAction
文本输入动作
final
textStyle → TextStyle?
文本样式
final

Methods

copyWith({double? maxHeight, Color? fillColor, InputBorder? border, InputBorder? focusedBorder, EdgeInsets? contentPadding, TextStyle? textStyle, String? hintText, TextStyle? hintStyle, Color? cursorColor, double? borderRadius, TextInputAction? textInputAction}) → RCKInputFieldConfig
getDecoration() → InputDecoration
获取输入框装饰
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited