RCKQuotePreviewConfig class

引用消息预览区域配置

Constructors

RCKQuotePreviewConfig({Color? backgroundColor, EdgeInsets? padding, TextStyle? textStyle, Icon? closeIcon})
const

Properties

backgroundColor → Color?
背景色
final
closeIcon → Icon?
关闭按钮图标
final
hashCode → int
The hash code for this object.
no setterinherited
padding → EdgeInsets?
内边距
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
文本样式
final

Methods

copyWith({Color? backgroundColor, EdgeInsets? padding, TextStyle? textStyle, Icon? closeIcon}) → RCKQuotePreviewConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited