RCKReferenceMessageBubble class

Inheritance

Constructors

RCKReferenceMessageBubble({Key? key, required RCIMIWMessage message, bool showTime = false, Alignment? alignment, bool? withoutBubble, RCKBubbleConfig? config, MessageTapCallback? onTap, MessageDoubleTapCallback? onDoubleTap, MessageLongPressCallback? onLongPress, MessageSwipeCallback? onSwipe})

Properties

alignment → Alignment?
finalinherited
config → RCKBubbleConfig?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message → RCIMIWMessage
finalinherited
onAppendBubbleLongPress → MessageLongPressCallback?
finalinherited
onAppendBubbleTap → MessageTapCallback?
finalinherited
onDoubleTap → MessageTapCallback?
finalinherited
onLongPress → MessageLongPressCallback?
finalinherited
onSwipe → MessageSwipeCallback?
finalinherited
onTap → MessageTapCallback?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showTime → bool
finalinherited
withoutBubble → bool?
finalinherited
withoutName → bool?
finalinherited

Methods

buildAppendBubble(BuildContext context) → Widget?
子类可重写:构建显示在主气泡下方的“追加气泡/附加面板”。
override
buildMessageContent(BuildContext context, String? refName) → Widget
override
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<RCKMessageBubble>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBubbleTap(BuildContext context) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited