RCKMessageEditScope class

聊天页面向编辑相关组件提供的只读配置作用域。

Constructors

RCKMessageEditScope({required bool enabled, required RCKMessageEditConfig config, Future<void> closeFullScreen()?})
const

Properties

closeFullScreen Future<void> Function()?
由聊天页根 Overlay 提供。动画完成前保持全屏编辑状态不变,避免同一 TextEditingController 同时挂到全屏和普通编辑输入框。
final
config RCKMessageEditConfig
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeOf(BuildContext context) RCKMessageEditScope?