RCKMessageInput class

Inheritance

Constructors

RCKMessageInput({Key? key, RCKMessageInputConfig? config, RCKMessageEditConfig? messageEditConfig, LeftButtonBuilder? leftButtonBuilder, RightButtonBuilder? rightButtonBuilder, TopButtonsBuilder? topButtonsBuilder, BottomButtonsBuilder? bottomButtonsBuilder, Widget emojiBuilder(BuildContext, dynamic (String), VoidCallback , VoidCallback )?, Widget gridBuilder(BuildContext)?, TapBeforePermissionCallback? onTapBeforePermission})

Properties

bottomButtonsBuilder → BottomButtonsBuilder?
底部按钮Builder
final
config → RCKMessageInputConfig
消息输入配置
final
emojiBuilder → Widget Function(BuildContext, dynamic (String), VoidCallback , VoidCallback )?
Emoji界面Builder
final
gridBuilder → Widget Function(BuildContext)?
扩展菜单Builder
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftButtonBuilder → LeftButtonBuilder?
左侧按钮Builder
final
messageEditConfig → RCKMessageEditConfig?
消息编辑配置。
final
onTapBeforePermission → TapBeforePermissionCallback?
点击权限弹窗之前回调
final
rightButtonBuilder → RightButtonBuilder?
右侧按钮Builder
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topButtonsBuilder → BottomButtonsBuilder?
顶部按钮Builder
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<RCKMessageInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited