RCKMessageList class

Inheritance

Constructors

RCKMessageList({Key? key, Map<RCIMIWMessageType, CustomChatItemBubbleBuilder>? customChatItemBubbleBuilders, Widget stickyHeaderBuilder(BuildContext context)?, RCKBubbleConfig? bubbleConfig, MessageTapCallback? onMessageTap, MessageDoubleTapCallback? onMessageDoubleTap, MessageLongPressCallback? onMessageLongPress, MessageSwipeCallback? onMessageSwipe, MessageTapCallback? onMessageAppendBubbleTap, MessageLongPressCallback? onMessageAppendBubbleLongPress})
const

Properties

bubbleConfig → RCKBubbleConfig?
气泡配置
final
customChatItemBubbleBuilders → Map<RCIMIWMessageType, CustomChatItemBubbleBuilder>?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onMessageAppendBubbleLongPress → MessageLongPressCallback?
消息追加气泡长按回调
final
onMessageAppendBubbleTap → MessageTapCallback?
消息追加气泡点击回调
final
onMessageDoubleTap → MessageTapCallback?
消息双击回调
final
onMessageLongPress → MessageLongPressCallback?
消息长按回调
final
onMessageSwipe → MessageSwipeCallback?
消息侧滑回调
final
onMessageTap → MessageTapCallback?
消息单击回调
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickyHeaderBuilder → Widget Function(BuildContext context)?
吸顶区域构建器,默认为null(不显示)
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → RCKMessageListState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited