RCKMessageReadReceiptBuildData class
Constructors
- RCKMessageReadReceiptBuildData({required RCIMIWMessage message, required RCKReadReceiptDisplayData displayData, required RCKReadReceiptIndicatorConfig config, VoidCallback? defaultOnTap})
-
const
Properties
- config → RCKReadReceiptIndicatorConfig
-
final
- defaultOnTap → VoidCallback?
-
final
- displayData → RCKReadReceiptDisplayData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → RCIMIWMessage
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited