RCKMessageEditInputConfig class
消息编辑输入区域配置。
Constructors
- RCKMessageEditInputConfig({int maxLength = 5000, double toolbarHeight = 44, double actionIconSize = 28, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 12, vertical: 6), Color? backgroundColor, Color? dividerColor, Color? actionColor, Color? disabledActionColor, TextStyle? textStyle, TextStyle? hintStyle})
-
const
Properties
- actionColor → Color?
-
可用操作图标颜色。
final
- actionIconSize → double
-
操作图标尺寸。
final
- backgroundColor → Color?
-
输入区域背景色。
final
- disabledActionColor → Color?
-
不可用操作图标颜色。
final
- dividerColor → Color?
-
输入区域顶部的分隔线颜色。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle?
-
输入提示文本样式。
final
- maxLength → int
-
编辑文本最大长度。
final
- padding → EdgeInsetsGeometry
-
输入区域内边距。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
编辑文本样式。
final
- toolbarHeight → double
-
工具栏高度。
final
Methods
-
copyWith(
{int? maxLength, double? toolbarHeight, double? actionIconSize, EdgeInsetsGeometry? padding, Color? backgroundColor, Color? dividerColor, Color? actionColor, Color? disabledActionColor, TextStyle? textStyle, TextStyle? hintStyle}) → RCKMessageEditInputConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited