RCKMessageEditStatusConfig class

消息编辑状态展示配置。

Constructors

RCKMessageEditStatusConfig({double iconSize = 12, double spacing = 4, TextStyle? editedTextStyle, Color? editedColor, TextStyle? updatingTextStyle, Color? updatingColor, TextStyle? failedTextStyle, Color? failedColor})
const

Properties

editedColor Color?
已编辑标记颜色。
final
editedTextStyle TextStyle?
已编辑标记的文本样式。
final
failedColor Color?
更新失败状态颜色。
final
failedTextStyle TextStyle?
更新失败的文本样式。
final
hashCode int
The hash code for this object.
no setterinherited
iconSize double
状态图标尺寸。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
图标与状态文本之间的间距。
final
updatingColor Color?
更新中状态颜色。
final
updatingTextStyle TextStyle?
更新中的文本样式。
final

Methods

copyWith({double? iconSize, double? spacing, TextStyle? editedTextStyle, Color? editedColor, TextStyle? updatingTextStyle, Color? updatingColor, TextStyle? failedTextStyle, Color? failedColor}) RCKMessageEditStatusConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited