RCKInputButtonConfig class

输入框旁边的功能按钮配置

Constructors

RCKInputButtonConfig({Widget? icon, Widget? activeIcon, double size = kInputFieldIconSize, double spacing = kInputFieldButtonSpace, Color? color, Color? activeColor, bool visible = true, RCKInputButtonAction? action})
const

Properties

action RCKInputButtonAction?
右侧按钮动作。
final
activeColor Color?
激活状态下按钮颜色
final
activeIcon Widget?
激活状态下的按钮图标
final
color Color?
按钮颜色
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
按钮图标
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
按钮尺寸
final
spacing double
按钮之间的距离
final
visible bool
按钮是否可见
final

Methods

copyWith({Widget? icon, Widget? activeIcon, double? size, double? spacing, Color? color, Color? activeColor, bool? visible, RCKInputButtonAction? action}) RCKInputButtonConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited