RCKMessageEditStatus class
文本和引用消息复用的编辑状态展示。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bubbleEditedColor(
RCIMIWMessage message) → Color - 返回消息气泡内“已编辑”标记的默认颜色。
-
buildAppend(
BuildContext context, RCIMIWMessage message) → Widget? -
buildEditedMark(
BuildContext context, RCIMIWMessage message, {Color? fallbackColor}) → Widget? -
buildEditedTextSpan(
BuildContext context, RCIMIWMessage message, {Color? fallbackColor, bool forceEdited = false}) → TextSpan? - 构建可直接追加到消息正文末尾的“已编辑”行内标记。
-
isEdited(
BuildContext context, RCIMIWMessage message) → bool -
messageForDisplay(
BuildContext context, RCIMIWMessage message) → RCIMIWMessage - 返回消息气泡应展示的有效消息。